@@ -37,6 +37,10 @@ our %NAMESPACES = (
 
    vcard       => 'vcard-temp',
    vcard_upd   => 'vcard-temp:x:update',
+
+   pubsub      => 'http://jabber.org/protocol/pubsub',
+   pubsub_own  => 'http://jabber.org/protocol/pubsub#owner',
+   pubsub_ev   => 'http://jabber.org/protocol/pubsub#event',
 );
 
 =head1 NAME
@@ -89,6 +93,10 @@ which make handling of namepsaces a bit easier:
 
    vcard       => vcard-temp
 
+   pubsub      => http://jabber.org/protocol/pubsub
+   pubsub_own  => http://jabber.org/protocol/pubsub#owner
+   pubsub_ev   => http://jabber.org/protocol/pubsub#event
+
 =head1 FUNCTIONS
 
 =over 4
