@@ -281,26 +281,27 @@ Where node is:
    <node> := {
                 ns => '<xmlnamespace>',
                 name => 'tagname',
-                attrs => [ ['name', 'value'], ... ],
+                attrs => [ 'name', 'value', 'name2', 'value2', ... ],
                 childs => [ <node>, ... ]
              }
            | {
                 dns => '<xmlnamespace>',  # this will set that namespace to
                                           # the default namespace before using it.
                 name => 'tagname',
-                attrs => [ ['name', 'value'], ... ],
+                attrs => [ 'name', 'value', 'name2', 'value2', ... ],
                 childs => [ <node>, ... ]
              }
+           | sub { my ($w) = @_; ... } # with $w being a XML::Writer object
            | "textnode"
 
 Please note: C<childs> stands for C<child sequence> :-)
 
-Also note that if you omit the C<ns> key for nodes there is a fallback
+Also note that if you omit the C<ns> key for nodes there is a fall back
 to the namespace of the parent element or the last default namespace.
 This makes it easier to write things like this:
 
    {
-      defns => 'muc_owner,
+      defns => 'muc_owner',
       node => { name => 'query' }
    }
 
@@ -309,6 +310,32 @@ This makes it easier to write things like this:
 Please note that all attribute values and character data will be filtered
 by C<filter_xml_chars>.
 
+This is a bigger example:
+
+   ...
+
+   $msg->append_creation( sub {
+      my($w) = @_;
+      simxml($w,
+         defns => 'muc_user',   # sets the default namepsace for all following elements
+         node  => {
+            name => 'x',        # element 'x' in namespace 'muc_user'
+            childs => [
+               {
+                  'name' => 'invite', # element 'invite' in namespace 'muc_user'
+                  'attrs' => [ 'to', $to_jid ], # to="$to_jid" attribute for 'invite'
+                  'childs' => [         
+                     { # the <reason>$reason</reason> element in the invite element
+                       'name' => 'reason', 
+                       childs => [ $reason ]
+                     }
+                  ],
+               }
+            ]
+         }
+      );
+   });
+
 =cut
 
 sub simxml {
@@ -332,6 +359,9 @@ sub simxml {
    if (not defined $node) {
       return;
 
+   } elsif (ref ($node) eq 'CODE') {
+      $node->($w);
+
    } elsif (ref ($node)) {
       my $ns = $node->{dns} ? $node->{dns} : $node->{ns};
       $ns    = $ns          ? $ns          : $desc{fb_ns};
@@ -350,8 +380,10 @@ sub simxml {
          if ($node->{defns}) { @args = (defns => $node->{defns}) }
 
          for (@{$node->{childs}}) {
-            if (ref ($_) && $_->{dns}) { push @args, (defns => $_->{dns}) }
-            if (ref ($_) && $_->{ns})  {
+            if (ref ($_) eq 'HASH' && $_->{dns}) {
+               push @args, (defns => $_->{dns})
+            }
+            if (ref ($_) eq 'HASH' && $_->{ns})  {
                push @args, (fb_ns => $_->{ns})
             } else {
                push @args, (fb_ns => $desc{fb_ns})
